package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````?1Y```````!``````````#"?````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````)"9````````D)D`````````
M$`````````$````&````D)D```````"0J4```````)"I0```````6`0`````
M```1!0`````````0`````````@````8```"0F0```````)"I0```````D*E`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````I)@```````"DF$```````*280```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```!1*0D`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````!D````2````````````
M`````````````#(````2`````````````````````````#@````2````````
M`````````````````$D````2`````````````````````````%`````2````
M`````````````````````%@````2`````````````````````````'(````2
M`````````````````````````)`````2`````````````````````````*0`
M```2`````````````````````````*L````2````````````````````````
M`+T````2`````````````````````````,L````2````````````````````
M`````-0````2`````````````````````````.,````2````````````````
M`````````.X````2`````````````````````````/P````2````````````
M``````````````8!```2``````````````````````````T!```2````````
M`````````````````!L!```2`````````````````````````"8!```2````
M`````````````````````#<!```2`````````````````````````#\!```2
M`````````````````````````%(!```2`````````````````````````&@!
M```2`````````````````````````&\!```2````````````````````````
M`(\!```2`````````````````````````*D!```2````````````````````
M`````+`!```2`````````````````````````+\!```2````````````````
M`````````-(!```2`````````````````````````-X!```2````````````
M`````````````/,!```2`````````````````````````/\!```2````````
M``````````````````\"```2`````````````````````````!8"```2````
M`````````````````````!T"```2`````````````````````````"("```2
M`````````````````````````"D"```2`````````````````````````#$"
M```2`````````````````````````#8"```6````````````````````````
M`#P"```2`````````````````````````$4"```2````````````````````
M`````$L"```2`````````````````````````%T"```2````````````````
M`````````&4"```2`````````````````````````&P"```2````````````
M`````````````(8"```2`````````````````````````(X"```2````````
M`````````````````)<"```2`````````````````````````)\"```2````
M`````````````````````,$"```2`````````````````````````,8"```2
M`````````````````````````,P"```2`````````````````````````-("
M```2`````````````````````````.4"```2````````````````````````
M`$T#```2`````````````````````````%L#```2````````````````````
M`````&H#```2`````````````````````````)$#```2````````````````
M`````````)P#```6`````````````````````````+\#```@````````````
M`````````````-D#```@`````````````````````````*\#```2````4!E`
M```````````````````$```1`!0`H*U````````(`````````,8!```2``P`
MP#=```````!1`````````%`"```2``P`("]```````"-!@```````/L#```2
M``P`\!M````````!`@```````!H$```2``T`:%)``````````````````"<#
M```2``P`4"A```````#O`0```````#0#```2``P`0"A````````#````````
M`'L#```2``P`L#5````````#`@```````/4#```2``H`^!=`````````````
M``````8````0`!$`Z*U```````````````````$````0`!$`H:Y`````````
M`````````+(````2``P`H$Y```````"@`0```````'0"```2``P`8"Y`````
M``"Q`````````.L"```2``P`@"Q```````"K`````````/,"```2``P`("Q`
M``````!9`````````!H#```2``P`0"I````````B`````````$4#```2``P`
M$"A````````H`````````'X!```2````0!M```````````````````X#```2
M``P`<"I```````!$`````````!(````0`!$`Z*U``````````````````"T!
M```1`!0`P*U````````(`````````)8!```2````,!M`````````````````
M`!,$```2``P`?1Y```````!-`0```````,(````2``P`0$Y```````!4````
M``````L$```1`!@``*Y````````(`````````*8"```2``P`0"Y````````=
M`````````-L"```1`!@`@*Y````````(`````````)H````2``P`0%!`````
M``#U`0```````%L!```1`!@`H*Y````````!``````````$#```2``P`P"I`
M``````!<`0```````&`````1`!@`0*Y```````!```````````!?96YD`%]?
M8G-S7W-T87)T`%]E9&%T80!M86QL;V,`1$8T,#0N,`!L:6)C+G-O+C@`86)O
M<G0`7U]S=&%C:U]C:&M?9F%I;`!S=')L96X`;65M;6]V90!S=')N8VUP`%]?
M<W1A8VM?8VAK7V=U87)D`%]R=&QD7V-A;&Q?:6YI=`!$1G!R:79A=&5?,2XP
M`%]I;FET7W1L<P!S:&%?9FEN86P`871E>&ET`&UE;6-P>0!S:&%?=7!D871E
M`&5X:70`<VAA7VEN:70`<&5R;%]R=6X`<&5R;%]C;VYS=')U8W0`<&5R;%]A
M;&QO8P!097)L7W-Y<U]T97)M`'!E<FQ?9G)E90!S='!C<'D`<&5R;%]D97-T
M<G5C=`!P97)L7W!A<G-E`'-T<F1U<`!M>5]P87)?<&P`<W1R<F-H<@!097)L
M7W-A9F5S>7-M86QL;V,`<F5A9&QI;FL`4$Q?9&]?=6YD=6UP`&%C8V5S<P!P
M=&AR96%D7V%T9F]R:P!097)L7V%T9F]R:U]L;V-K`&UE;6-H<@!097)L7V%T
M9F]R:U]U;FQO8VL`<W1R8VUP`%!E<FQ?<WES7VEN:70S`'-T<G1O:P!P87)?
M8VQE86YU<`!097)L7VUG7W-E=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7V=E=%]S=@!097)L7V=V7V9E=&-H<'8`<W1R8VAR`&=E='!I9`!O<&5N`'5N
M;&EN:P!F<')I;G1F`'-T870`97)R;F\`8VQO<V5D:7(`;6MD:7(`9G)E90!P
M87)?;6MT;7!D:7(`;W!E;F1I<@!S=')S='(`<F5A;&QO8P!P87)?<V5T=7!?
M;&EB<&%T:`!S<')I;G1F`&=E='!W=6ED`')E861D:7(`9V5T=6ED`&=E=%]U
M<V5R;F%M95]F<F]M7V=E='!W=6ED`')E860`;'-T870`;'-E96L`=F9P<FEN
M=&8`7U]S=&1E<G)P`')M9&ER`'!A<E]D:64`<&%R7V5N=E]C;&5A;@!P87)?
M:6YI=%]E;G8`<&%R7V1I<FYA;64`<&%R7V)A<V5N86UE`'!A<E]F:6YD<')O
M9P!P87)?8W5R<F5N=%]E>&5C`'AS7VEN:70`4&5R;%]S=E]S971P=@!097)L
M7W-V7W-E='!V;@!097)L7VYE=UA37V9L86=S`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!097)L7VYE=UA3`%!,7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,
M;V%D97(`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?251-7V1E<F5G:7-T
M97)434-L;VYE5&%B;&4`7VEN:70`;6%I;@!?7W!R;V=N86UE`&5N=FER;VX`
M7W-T87)T`%]F:6YI`&QI8G!E<FPN<V\N-2XS-@!L:6)P=&AR96%D+G-O+C``
M;&EB9&PN<V\N,`!L:6)M+G-O+C0`;&EB8W)Y<'0N<V\N-`!L:6)U=&EL+G-O
M+C0`+W5S<B]L:6(O9V-C.#`Z+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XS-B]M
M86-H+T-/4D4````````1````/P````0````(````(!P0``5`!(`H```$@(8!
MC,*A`2))``0;B((X0;H$`@@_````00```$4```!)````2@```%$```!2````
M4P```%4```!6````5P```%@```!9````6P```%P`````````7@```'KP2FN]
M4':>;L7?'\[>1RUJ?YI\Z]/O#B#_Y`XNQ9NVU&34?+F-\0[9<5@<NN.2?$+Z
MUX?ZH6Q@F$_#F[(!BV_B1\8!P^4_+(?YG(%GK\QF0D75[(D'<-/)U;)Q,V+;
M[16,)<RGW:-K?JF<F^<5`X-K&IY0"HH05Z/@^TDA8F0'```"``(``@`"``(`
M`@`#``,``@`"``(```````````````(```````(``@````(``@`"``(``@``
M``(````````````"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(`
M`@`"``(``@`"```````````````````````!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$````!``$``0````$``0`!``$``@`!``$``0`"````
M`0`"`"@````0`````````%`WEP@```(`(````!````"0M'X````#`((`````
M`````````)BK0```````$@```"@``````````````)"K0```````$@```#P`
M`````````````("N0```````!0```%H``````````````*"N0```````!0``
M`%P``````````````$"N0```````!0```%X``````````````+BK0```````
M!P````(``````````````,"K0```````!P````@``````````````,BK0```
M````!P````<``````````````-"K0```````!P````D``````````````-BK
M0```````!P````L``````````````."K0```````!P````8`````````````
M`.BK0```````!P````,``````````````/"K0```````!P````0`````````
M`````/BK0```````!P````$```````````````"L0```````!P````4`````
M``````````BL0```````!P```"X``````````````!"L0```````!P```"P`
M`````````````!BL0```````!P```#$``````````````""L0```````!P``
M`"\``````````````"BL0```````!P```"<``````````````#"L0```````
M!P```"4``````````````#BL0```````!P```"L``````````````$"L0```
M````!P```"D``````````````$BL0```````!P```#<``````````````%"L
M0```````!P```#\``````````````%BL0```````!P```#L`````````````
M`&"L0```````!P```#0``````````````&BL0```````!P```!@`````````
M`````'"L0```````!P```!<``````````````'BL0```````!P```!H`````
M`````````("L0```````!P```#D``````````````(BL0```````!P```#@`
M`````````````)"L0```````!P```!$``````````````)BL0```````!P``
M`!4``````````````*"L0```````!P```!0``````````````*BL0```````
M!P```"(``````````````+"L0```````!P```!T``````````````+BL0```
M````!P```!L``````````````,"L0```````!P```#8``````````````,BL
M0```````!P```#4``````````````-"L0```````!P```#,`````````````
M`-BL0```````!P```#(``````````````."L0```````!P```#``````````
M`````.BL0```````!P```"T``````````````/"L0```````!P```"H`````
M`````````/BL0```````!P```"8```````````````"M0```````!P```"0`
M``````````````BM0```````!P```",``````````````!"M0```````!P``
M`"$``````````````!BM0```````!P```"```````````````""M0```````
M!P```!\``````````````"BM0```````!P```!X``````````````#"M0```
M````!P```#H``````````````#BM0```````!P```!P``````````````$"M
M0```````!P```%4``````````````$BM0```````!P```%$`````````````
M`%"M0```````!P```!D``````````````%BM0```````!P```!8`````````
M`````&"M0```````!P```!,``````````````&BM0```````!P```!(`````
M`````````'"M0```````!P```!```````````````'BM0```````!P````\`
M`````````````("M0```````!P````X``````````````(BM0```````!P``
M``T``````````````)"M0```````!P````P``````````````)BM0```````
M!P````H``````````````$B#[`CHB`@``.@O.@``2(/$",,``````/\UDI,`
M`/\EE),``)"0D)#_)9*3``!H`````.G@_____R6*DP``:`$```#IT/____\E
M@I,``&@"````Z<#_____)7J3``!H`P```.FP_____R5RDP``:`0```#IH/__
M__\E:I,``&@%````Z9#_____)6*3``!H!@```.F`_____R5:DP``:`<```#I
M</____\E4I,``&@(````Z6#_____)4J3``!H"0```.E0_____R5"DP``:`H`
M``#I0/____\E.I,``&@+````Z3#_____)3*3``!H#````.D@_____R4JDP``
M:`T```#I$/____\E(I,``&@.````Z0#_____)1J3``!H#P```.GP_O___R42
MDP``:!````#IX/[___\E"I,``&@1````Z=#^____)0*3``!H$@```.G`_O__
M_R7ZD@``:!,```#IL/[___\E\I(``&@4````Z:#^____)>J2``!H%0```.F0
M_O___R7BD@``:!8```#I@/[___\EVI(``&@7````Z7#^____)=*2``!H&```
M`.E@_O___R7*D@``:!D```#I4/[___\EPI(``&@:````Z4#^____);J2``!H
M&P```.DP_O___R6RD@``:!P```#I(/[___\EJI(``&@=````Z1#^____):*2
M``!H'@```.D`_O___R6:D@``:!\```#I\/W___\EDI(``&@@````Z>#]____
M)8J2``!H(0```.G0_?___R6"D@``:"(```#IP/W___\E>I(``&@C````Z;#]
M____)7*2``!H)````.F@_?___R5JD@``:"4```#ID/W___\E8I(``&@F````
MZ8#]____)5J2``!H)P```.EP_?___R52D@``:"@```#I8/W___\E2I(``&@I
M````Z5#]____)4*2``!H*@```.E`_?___R4ZD@``:"L```#I,/W___\E,I(`
M`&@L````Z2#]____)2J2``!H+0```.D0_?___R4BD@``:"X```#I`/W___\E
M&I(``&@O````Z?#\____)1*2``!H,````.G@_/___R4*D@``:#$```#IT/S_
M__\E`I(``&@R````Z<#\____)?J1``!H,P```.FP_/___R7RD0``:#0```#I
MH/S___\EZI$``&@U````Z9#\____)>*1``!H-@```.F`_/___R7:D0``:#<`
M``#I</S___\ETI$``&@X````Z6#\____)<J1``!H.0```.E0_/___R7"D0``
M:#H```#I0/S___\ENI$``&@[````Z3#\____);*1``!H/````.D@_/__4TB#
M[#!(BP5$D@``2(E$)"@QP(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(
MZ/O^__^Z,!M``+]`&T``2(G6Z!G___^`/6*2````#X00`0``9$B+%"4`````
M2(L%/(\``$B+!`*`B+(#```#BT0D'(UX!(U8`TAC_TC!YP/HZ_[__TB+?"00
MBTPD'$B)!:.1``!(BQ=(QT`(<%1``$C'0!AS5$``2(D02(L5'I$``$B)4!"#
M^0$/CBD!``!(@\<(@\$#O@0````/'T0``$B+%TQCQH/&`4B#QPA*B13`.<YU
MZTAC]DC!Y@-(QP0P`````$4QP$B)P8G:2(L]/9$``+Z0)4``Z'/^__^%P`^$
MB````$B+/221``#H;_[__TB-="0DOQI30`")PS'`Z(P#``!(A<!T=4B+/0"1
M``#H6_[__^AF_O__B=A(BUPD*$@S'?B0```/A9X```!(@\0P6\/H5_[__TB)
M!="0``!(A<!T?4B)Q^A3_O__2(L%'(X``&1(BQ0E`````$B+#`+&@?\(````
MZ<?^__](BSV<D```Z#?^___I9____TB+/7N0``!(A?]T"N@1&@``Z77___^_
MR%)``$B-="0DZ.T"``!(B<=(B053D```2(7`#X13____Z]*^(````.GZ_O__
MOP$```#H=/K__^B/^O__N`````!(/0````!S.E5(B>5!5%.#/?SAO_\E=2!(
MB<-,BR/_4Q!)B00D2(/#&$B!^P````!S"X-[""5TX^CM^?__6T%<7</#54B)
MY5-(@^P(N`````!(+0````!(P?@#2(G#=1'H#30``$B#Q`A;7<-(A=MT[TB#
MZP%(BP3=`````$B#^`%VZ?_0Z^552(GE05=!5D%505132(/L&$B)\TR++T6)
M[TR-=PA)8\5,C63'$$B#/56/````=%=%A>U^%TB+1PA(A<!T#DB)!=Z.```/
MMA"$TG5/Z&+Y___H;?G__[B0J4``2(7`=$U(B=_H:_G__[B0J4``2(7`=$),
MB>),B?9$B>_H\_S__XG'Z%SY__],B27UC@``ZZ!(@\`!#[80A-)TL8#Z+W7P
M2(U0`4B)%7B.``#KX^C"_O__Z[2_.1Y``.@5^?__N`````!(+0````!(P?@#
M2(E%R'0LNP````#K"DB#PP%(.5W(=!M(BP3=`````$B#^`%VZ$R)XDR)]D2)
M___0Z]OH=_C__[@`````2"T`````2,'X`TB)1<@/A%7___^[`````.L.2(/#
M`4@Y7<@/A$#___](BP3=`````$B#^`%VY$R)XDR)]D2)___0Z]>XZ*U``$@]
MZ*U``'07N`````!(A<!T#55(B>6_Z*U``/_07</#ONBM0`!(@>[HK4``2,'^
M`TB)\$C!Z#](`<9(T?YT%[@`````2(7`=`U52(GEO^BM0`#_T%W#PX`]VXT`
M``!U655(B>5!5%.[X*U``$B!Z]BM0`!(P?L#2(/K`4&\V*U``$B+!;F-``!(
M.=AS&TB#P`%(B06IC0``0?\4Q$B+!9Z-``!(.=ARY>A.____Q@6%C0```5M!
M7%W#PU5(B>7H7?___UW#9F9F9BX/'X0``````````````````````````$%7
M059!54%455-(@^P(2(7_#X2K````3(L],HT``$V%_P^$FP````^V!X3`=`0\
M/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB3(GV2(G?Z&+W
M__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G86UU!7$%=05Y!7\,/
M'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/'X``````3"G]2HU<
M(P%(P?T#08EM`.NT,=OKL&8N#Q^$``````!32(G[2(/L$$B+!;&,``!(B40D
M"#'`9BX/'X0``````#'`2(UT)`1(B=_H`?___TB%P'0N2&-4)`1(BP5`C```
M2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#KODB+1"0(2#,%4HP`
M`'4&2(/$$%O#Z(7V__\/'T0``$%7059!54%454B)]5-(B?M(@^PH2(L%)8P`
M`$B)1"08,<`QP(`^/0^4P$@!Q4B)[^A;]O__2(UT)!1(B=])B<0QP.AI_O__
M2(7`#X0$`0``2(G'28G%Z#7V__],.>`/@]````!,8W0D%$G!Y@,/M@.$P`^$
MG`$``#P]#X24`0``2(G82(/``0^V$(32=`6`^CUU\$@IV$B82HU\(`),`S5<
MBP``Z/?U__])B09(A<`/A',!``!(BP5$BP``2&-4)!1(C4L!2(L4T`^V`X@"
MA,!T)#P]=0[K'@\?A```````A,!T$DB#P0$/MD'_2(/"`8@"/#UUZL8"/3'`
M#Q]$```/MDP%`(A,`@%(@\`!A,EU[S'`2(M<)!A(,QTABP``#X4-`0``2(/$
M*%M=05Q!74%>05_#,<!F+@\?A```````#[94!0!!B%0%`$B#P`&$TG7NZ[U,
MBSVEB@``28,_``^$M@```$R)^#'2ZP</'T``1(GJ2(/`"$2-:@%(@S@`=>^-
M<@-(8_9(P>8#BP6'B@``A<!U6\<%>8H```$```!(B??H^?3__TB%P'1\36/%
M3(G^2(G'3HTTQ0````!,B40D"$R)\NCF]/__3(M$)`A(B04JB@``2(G!2L=$
MP0@`````1(EL)!3I@?[__P\?0`!,B?_HR/3__TB)P4B)!?Z)``!(A<!T(4UC
MQ4Z--,4`````Z\4QP.E]_O__OA````!%,>WI8____[C_____Z>'^___H2?3_
M_V8/'X0``````$%505154TB![)@```!(BP7LB0``2(F$)(@````QP$B%_W0(
M@#\`2(G]=25(BX0DB````$@S!<:)```/A?P```!(@<28````6UU!7$%=PV:0
MZ#OT__])B<1(A<!TSDR)Y^@[]/__2(7`#X2R````2(U8$+]Y4D``N0(```!(
MB=[SI@^7P!P`A,!TT[][4D``N0,```!(B=[SI@^7P!P`A,!TNTB)[^BF\___
M2(G?28G%Z)OS__]!C7P%`DAC_^B>\___2(G92(GJOGY20`!)B<5(B<<QP.C6
M\___3(GO2(GFZ-OS__],B>^#^/]T#P^W1"009B4`\&8]`$!T.>C/\___3(GO
MZ-?S__],B>?HC_/__TB%P`^%5/___V8/'T0``$R)Y^C(\___2(GOZ-#S___I
M]O[__^C&_O__Z\7H__+__V9F+@\?A```````#Q]``%6Y`)-``+I0&4``OH12
M0`!32(/L"$B+'>2%``!D2(LL)0````!(BWP=`.BA\___2(M\'0!!N'A20`!(
M@\0(6T4QR4R)P;JP-4``OJ!20`!=Z2OU__]F9BX/'X0``````%-(B?M(@>R0
M````2(L%/H@``$B)A"2(````,<!(B>;H7//__X7`=3@/MU0D$('B`/```('Z
M`$```'0(@?H`H```=1^^`@```$B)W^A`\___A<`/E,`/ML#K"&8/'T0``#'`
M2(N,)(@```!(,PW?AP``=0E(@<20````6\/H#_+__V9F+@\?A```````#Q]`
M`$%5NO\#``!)B?5!5$F)_+^U4D``55-(@>P8!```2(L%G(<``$B)A"0(!```
M,<!(B>;HVO+__X7`?G:-4/](BPW,A```9$B+-"4`````2&/:@#P<`$B++`YU
M2872=&9(B=J^+P```$B)Y^BR\O__2(7`=%%(B=E(B>),B>9(B>_HK/+__TB+
MA"0(!```2#,%+8<``'4_2('$&`0``%M=05Q!7<-(8]CKM@\?A```````9$B+
M%"4`````2(L%4(0``$B++`),B>I,B>9(B>_H;O+__^NPZ"?Q__\/'X``````
M4TB)_DB![!`$``!(BP7.A@``2(F$)`@$```QP$B)XTB)W^A)\O__2(/H`4@Y
MV'<.ZQ'&``!(@^@!2#G8=`6`."]T[[XO````2(G?Z##R__](A<!T,$@YV'<F
M2(G?Z"[R__](BY0D"`0``$@S%6^&``!U-4B!Q!`$``!;PP\?0`#&``#KU4B+
MA"0(!```2#,%3(8``'422('$$`0``+]Y4D``6^GH\?__Z'/P__\/'P!D2(L4
M)0````"Y`)-``+Z$4D``2(L%9H,``$B+/`*Z4!E``.DH\?__#Q^$```````Q
MP,-F9BX/'X0``````&:0055)B?V_R%)``$%455-(B?-(@>R8!```2(L%T84`
M`$B)A"2(!```,<!(B>;H+_C__[XO````3(GO2(G%Z&_Q__](A<!T.DR)[K_1
M4D``,<#H6_G__TR)Z$B+E"2(!```2#,5B84```^%?0$``$B!Q)@$``!;74%<
M05W##Q]$``!(B=_H&/'__[[>4D``2(G'Z"OQ__](B<-(A<!TJ8`[``^$VP``
M`&8N#Q^$``````!(A>UT$TB)WDB)[^@0\?__A<`/A)@```!(B=_H<.___TB-
M3`/_28G$2#G+<R.`.2]T!^L<@#DO=0S&`0!(@^D!2#G+=>](B=_H0^___TF)
MQ$R)[^@X[___28U$!`%(/?\#```/ARW___^^XE)``#'`38GHN>!20`!(C;PD
M@````$B)VNAH[___2(GF2(V\)(````#H:.___X7`=10/MT0D$&8E`/!F/0"`
M=%4/'T0``+[>4D``,?_H5/#__TB)PTB%P`^$SO[__X`[``^%+____TB%[709
MN0(```"_>5)``$B)[O.F#Y?"@-H`A-)TP4&\`0```+MY4D``Z5'___^0O@$`
M``!(C;PD@````.AN[___A<!UFDB-M"2`````O]%20`#HV/?__TB-O"2`````
MZ+OO___I;O[__^A![O__D%.^+P```$B)^^B2[___2(U0`4B%P$@/1=I(B=];
MZ8[O__]F9BX/'X0```````\?`$B%_W0K@#\`="932(G[Z`WN__](@\`!2#T`
M!```=R%(B=];Z<C\__\/'X0``````+]Y4D``Z4;O__]F#Q]$```QP%O#9F8N
M#Q^$``````"02(/L&+_I4D``2(L%<(,``$B)1"0(,<#HI/;__S'`O_)20`#H
MF/;__S'`O_I20`#HC/;__S'`OP-30`#H@/;__S'`OPI30`#H=/;__S'`OQI3
M0`#H:/;__S'`O\A20`#H7/;__S'`OR930`#H4/;__S'`OS!30`#H1/;__S'`
MOSI30`#H./;__S'`O]%20`#H+/;__S'`2(UT)`2_1%-``.A+]?__2(7`=`](
MB<:_,%-``#'`Z(?V__\QP$B-="0$OU530`#H)O7__TB%P'0/2(G&OV=30``Q
MP.AB]O__,<!(C70D!+]R4T``Z`'U__](A<!T/$B)QK_(4D``,<#H/?;__S'`
MOI-30`"_"E-``.@L]O__2(M$)`A(,P5@@@``=35(@\08PV8/'X0``````#'`
M2(UT)`2_@E-``.BO]/__2(7`=+U(B<:_)E-``#'`Z.OU___KK.AD[/__#Q]`
M`$B#[!B_)E-``$B+!1""``!(B40D"#'`2(UT)`3H;_3__TB%P'0J#[80@/HP
M#Y3`A-(/E,()T(/P`0^VP$B+3"0(2#,-V($``'4*2(/$&,.0,<#KZ.@'[/__
M#Q^``````$B![-@```!(B70D*$B)5"0P2(E,)#A,B40D0$R)3"1(A,!T-P\I
M1"10#RE,)&`/*50D<`\IG"2`````#RFD))`````/*:PDH`````\IM"2P````
M#RF\),````!(BP5>@0``2(E$)!@QP$B)_DB-A"3@````2(L]A8$``$B)1"0(
M2(GB2(U$)"#'!"0(````QT0D!#````!(B40D$.@/[?__O_\```#H->O__P\?
M1```052Z`@```#'V08G\55-(@>P0``$`2(L%](```$B)A"0(``$`,<!(B>7H
MXNS__TB#Z`%(B<%(P?D_2,'I,$B-%`@/M])(*<I(*=!(B<,/B)$````QTDB)
MWD2)Y^BP[/__2(/X_P^$CP```+H(``$`2(GN1(GGZ*;L__^#^/]T;DB82(/X
M!W9)2(U$!?A(.>AS"^L]2(/H`4@YZ'(T2(L-W7\``$@Y"'7K2"GH2`'82(NT
M)`@``0!(,S53@```=49(@<00``$`6UU!7,,/'T0``$B!ZP```0!(@?L``/__
M#X5O____2,?`_____^O!OZ)30``QP.A7_O__OY530``QP.A+_O__Z$;J__]F
M#Q]$``!(@^P(Z!?L__^)Q^@@[/__2(7`=`-(BP!(@\0(PP\?`$%454B)_;^N
M4T``4TB#[!!(BP7)?P``2(E$)`@QP$B-="0$Z"CR__](B>Y(A<!T"(`X`$B)
MPW4HOZY30``QP.A<\___2(M$)`A(,P60?P``=5I(@\006UU!7,,/'T0``$B)
MQ^BXZ___2(7`===(B>_HN^G__TB)WTF)Q.BPZ?__28U\!`+HMNG__[[B4D``
M28G82(GJ28G$2(G'N=Y20``QP.CIZ?__3(GFZXSH;^G__V9F+@\?A```````
M#Q]``$%6055)B?V_R%)``$%455-(@>Q0`0``2(L%`G\``$B)A"1(`0``,<!(
MC70D$$C'A"20````RE-``$C'A"28````>5)``$C'A"2@`````````$C'A"30
M````9U-``$C'A"38````T%-``$C'A"3@````UU-``$C'A"3H````WU-``$C'
MA"3P````Y%-``$C'A"3X`````````$C'A"2P````OE-``$C'A"2X````Z%-`
M`$C'A"3``````````.C.\/__2(7`=`F`.``/A6`$```QP.A)_O__2(G#2(7`
M#X3=`P``2(G?Z(7H__](C7P``>B+Z/__@#L`28G$="),B>4/MA-(B>\QP+[Q
M4T``2(/#`4B#Q0+HMNC__X`[`'7A2(V<)-@```"_9U-``.L39I!(@\,(2(M[
M^$B%_P^$<P$``$B-="00,<#H0_#__TB)Q4B%P'3;@#@`=-9(B<?H;O7__X7`
M=,I(B>_H8NG__TB)PTB%P`^$.@$``&8/'T0``$B)WHL62(/&!(V"__[^_O?2
M(=`E@("`@'3IB<+!ZA"I@(````]$PDB-5@)(#T3RB<$`P4R)X4B#W@-(*=Z+
M.4B#P02-A__^_O[WUR'X)8"`@(!TZ8G"P>H0J8"````/1,)(C5$"2`]$RHG"
M`,)(@]D#3"GAC:P.!`0``$AC[4B)[^AZY___OOM30`!-B>%(B=I(B<=)B<9!
MN/930``QP+G@4D``Z*?G__^^P`$``$R)]^@ZZ?__@_C_=1YD2(L4)0````!(
MBP4M>@``1(L$`D&#^!$/A;4"``!(C70D$$R)]^CJY___B<.%P`^$L````$F+
M50!(BSWE?```3(GQ,<"^P%1``#'MZ/3H__](BXPD2`$``$@S#85\``!(B>@/
MA=@#``!(@<10`0``6UU!7$%=05[#,>UF+@\?A```````2&/%2(N<Q)````!(
MA=MT0(`[`'0[2(G?@\4!Z/#S__^%P'3<2(G?Z.3G__](B<-(A<`/A8C^__](
M8\5(BYS$D````$B%VW7(#Q^$```````QV^EI_O__9@\?A```````#[=$)"!F
M)0#P9CT`0`^%/?___T2+9"0DZ`/H__]!.<0/A2K___\/MT0D(&8E_P%F/<`!
M#X47____2(GOZ!_F__](C70D$+\$5$``2(G%,<#H&^[__TB%P`^$\@$``$F+
M?0!(B<;HIO7__TF)Q$B%P`^$V@$``$R)Y^C2Y?__@_@#?CU(8]"_"51``+D%
M````28UT%/SSI@^7PH#:`(32=1^#^`0/A'("``"#Z`1(F$&`?`3_+P^$80(`
M``\?1```,<#H&?G__X7`=15,B><Q]NB;Y___08G$A<`/A7D!``"^DU-``+\F
M4T``,<#HS^[__^B*Y___N>!20`!,B?)(B>]!B<!!N7A20`"^+51``#'`Z)KE
M___K3@\?A```````9$B+%"4`````2(L%*'@``(,\`A%U0NA%Y___2(/L"(/#
M`4R)\FAX4D``08G`08G9N>!20`"^.U1``$B)[S'`Z$SE__]86K[``0``2(GO
MZ-WF__^#^/]TJ$R)]^A@Y?__2(GNO\A20``QP.@Q[O__2(GOZ(GZ___IT/W_
M_P\?0`"_OE-``#'MZQ(/'X``````2&/%2(N\Q+````!(A?]T<DB-="00,<"#
MQ0'HH>S__TB%P'3<@#@`=-=(B<?HS^7__TB)PTB%P'3'Z=7[__])BU4`2(L]
M1WH``$R)\3'`OGA40``Q[>A6YO__Z5W]__^02(G'2(E$)`CH`_K__TB+1"0(
M2(G'Z(;E__](B<7I.OW__[\-````N\-30`#H'^3__TF)Q.F4^___#Q^`````
M`$V+90#I'?[__XG'Z)#X__])B<5(A<`/B'3^__\QTDB-</9$B>?HAN7__[H&
M````2(VT)`H!``!$B>?H@>7__TB#^`8/A<@```"+!1E>```YA"0*`0``#X4T
M_O__#[<%"5X``&8YA"0.`0``#X4?_O__,=))C77.1(GGZ#'E__^Z*````$B-
MM"00`0``1(GGZ"SE__](@_@H=7=!N7A20`"YX%)``$R)\C'`3(V$)!`!``"^
M'E1``$B)[\:$)#@!````Z)GC___I7/[__TV+;0A-A>T/A)?]__],B>_H'^/_
M_TB#^`,/AH7]__])C70%_+\.5$``N04```#SI@^7P!P`A,!-#T3EZ63]___H
MW^+__[\35$``,<#HT_;__P\?`$%4OPI30`!54TB#[!!(BQW,=0``9$B++"4`
M````2(L%;'@``$B)1"0(,<!(C70D!$B+1!T`#[:0L````(B0L0```#'`Z+?J
M__](A<!T"8`X,0^$2P$``#'`Z++T__](BWP=`+D#````N@$```"^3%1``.BI
MY/__28G$2(7`="A(BT`02(M\'0"Z3E1``$B+,.A[X___28M$)!!(BS#V1@Y`
M#X4I`0``2(M\'0"Y`P```+H!````OE-40`#H8.3__TF)Q$B%P'0O,<!(C70D
M!+_14D``Z"?J__](A<`/A,\```!)BTPD$$B+?!T`2(G"2(LQZ!GC__](BWP=
M`+H!````OE540`#H)>3__TB+?!T`NFI40`!(B<;H\^+__TB+1!T`2(UT)`2_
MR%)``,:`L0`````QP.C&Z?__2(D%+W<``$B%P'0ZOL`!``!(B<?HC>/__XU0
M`8/Z`78%@_@1=7](BT0D"$@S!21W```/A8P```!(@\006UU!7,,/'T0``$B+
M/?%V``#HY/?__TB)!=UV``!(A<!UKK\854``Z)[C__^`>`$`#X2R_O__Z:;^
M__])BT0D$$B+%;MV``!(BSA(BS+H".___^DJ____#Q\`2(M\'0#H=N/__^G(
M_O__B<%(BP60=@``2(L5@78``+]`54``2(LP,<#H0N/__^C-X/__9F8N#Q^$
M``````!FD%,QP$B)^^A5]/__2(7;=`F%P'0%@#L`=0=;PP\?1```2(G?Z(CR
M__](B<?H4/+__[_V4T``N00```!(B<;SI@^7P!P`A,!UT4B)WUOI+^S__V9F
M9F9F9BX/'X0``````&9F9F9F9BX/'X0```````!!5TR-3SA!5D%505154TB!
M[)@"``!(BP7T=0``2(F$)(@"```QP$B)XDR-DH````!)B=!!BP%)BS%)@\`0
M28/!"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(
M2,'F&('A``#_`(GV2`GP2`G(28E`^$TYPG6N2(VR``(```\?0`!(BT)H2#-"
M0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L72(M?$$B+
M=R!(BV\83(G03(G23(M/"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DB)V$B+="0(
M2#'H3"'(2(VT-9EY@EI(,>A$C2P"3(G*3(G(2,'H`DC!XAY-B>A("<)(B=A)
MP>@;B=%(,<A,(=!(,=A(`?!,B>Y(P>8%3`G&1(TD!DR)UDR)T$C!YAY(P>@"
M38GC2`GP2(MT)!!)P>L;2#'"08G`3"'J2(VT,YEY@EI(,<I(`?),B>9(P>8%
M3`G>1(T<%DR)[DG![0)(BU0D&$C!YAY,">Y(C901F7F"6DR)V4@Q\$&)]DPA
MX$PQP$C!Z1M(`=!,B=I(P>(%2`G*3(GA2<'L`DC!X1Y$C2P"2(GP2(M4)"!,
M">%,B>Y(,<A)C900F7F"6DC![AM!B<Q,(=A,,?!(`=!,B>I(P>(%2`GR1(T$
M`DR)VDG!ZP)(BT0D*$C!XAY,B<9,"=I)C80&F7F"6DC![AM(,=%!B=-,(>E,
M,>%(`<%,B<!(P>`%2`GP1(TT"$R)Z$G![0)(BTPD,$C!X!Y,B?9,">A)C8P,
MF7F"6D@QPD&)Q4PAPDPQVD@!RDR)\4C!X05(P>X;2`GQ3(G&2<'H`DC!YAY$
MC2012(M4)#A,"<9,B>%(,?!)C903F7F"6DC!Z1M!B?!,(?!,,>A(`=!,B>)(
MP>(%2`G*3(GQ2<'N`DC!X1Y$C1P"2(GP2(M4)$!,"?%,B=Y(,<A)C905F7F"
M6DC![AM!B<Y,(>!,,<!(`=!,B=I(P>(%2`GR1(TL`DR)XDG![`)(BT0D2$C!
MXAY,B>Y,">))C80`F7F"6DC![AM(,=%!B=1,(=E,,?%(`<%,B>A(P>`%2`GP
M1(T$"$R)V$G!ZP)(BTPD4$C!X!Y,B<9,"=A)C8P.F7F"6DC![AM(,<)!B<-,
M(>I,,>)(`<I,B<%(P>$%2`GQ3(GN2<'M`DC!YAY$C3012(M4)%A,">Y,B?%(
M,?!)C904F7F"6DC!Z1M!B?5,(<!,,=A(`=!,B?)(P>(%2`G*3(G!2<'H`DC!
MX1Y$C20"2(GP2(M4)&!,"<%,B>9(,<A)C903F7F"6DC![AM!B<A,(?!,,>A(
M`=!,B>)(P>(%2`GR1(T<`DR)\DB+1"1H2,'B'DG![@),B=Y,"?))C80%F7F"
M6DC![AM(,=%!B=9,(>%,,<%(`<%,B=A(P>`%2`GP1(TL"$R)X$G![`)(BTPD
M<$C!X!Y,B>Y,">!)C8P(F7F"6DC![AM(,<)!B<1,(=I,,?)(`<I,B>E(P>$%
M2`GQ3(G>2<'K`DC!YAY$C0012(M4)'A,"=Y,B<%(,?!)C906F7F"6DC!Z1M!
MB?-,(>A,,>!(`=!,B<)(P>(%2`G*3(GI2<'M`DC!X1Y$C30"2(GP2(N4)(``
M``!,">E,B?9(,<A)C904F7F"6DC![AM!B<U,(<!,,=A(`=!,B?)(P>(%2`GR
M1(TD`DR)PDG!Z`)(BX0DB````$C!XAY,B>9,"<))C80#F7F"6DC![AM(,=%!
MB=!,(?%,,>E(`<%,B>!(P>`%2`GP2(NT))````!$C1P(3(GP2<'N`DC!X!Y)
MC;0UF7F"6DV)W4P)\$G![1M(,<*)P4PAXDPQPD@!\DR)WDC!Y@5,">Z)]D@!
M\DR)YDG![`)(P>8>08G53`GF3(ND))@```!(,?!,(=A/C80@F7F"6DV)[$@Q
MR$G![!M,`<!-B>A)P>`%30G@18G`3`'`38G82<'K`DG!X!Y!B<1-"=A)B?.)
M]D@#M"2H````33'#1#':3(N<)*````!*C8P9H>O9;DV)XT@!T4R)XDG!ZQM(
MP>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"2P````23'5
M1#'H38G=2(VT!J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!
MB<5,">9)B=2)TDDQ]$0QX4V)[$@#E"2X````38V$"*'KV6Y,B>E)P>P;2,'A
M!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)]D@#M"3`````23'+1#'8
M38GC2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'"3(GH2<'M`DC!X!Y!B=-,
M">A)B<V)R4@#C"3(````23'%13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)
M[HGV3`'&38G@2<'L`DG!X!Y!B?5-">!)B<2)P$TQQ$0QXDV)[$B-C!&AZ]EN
M3(GJ2,'B!4G![!M(`X0DT````$P)XHG22`'13(G:2<'K`DC!XAY!B<Q,"=I-
MB<-%B<!,`X0DV````$DQTT0QWDV)XTB-M#"AZ]EN3(G@2<'K&TC!X`5,"=B)
MP$@!\$R)[DG![0)(P>8>08G#3`GN28G5B=)(`Y0DX````$DQ]40QZ4V)W4V-
MA`BAZ]EN3(G92<'M&TC!X05,">F)R4D!R$R)X4G![`)(P>$>18G%3`GA28GT
MB?9),<Q$,>!-B>Q(C90"H>O9;DR)Z$G![!M(P>`%3`G@B<!(`<),B=A)P>L"
M2`.T).@```!(P>`>08G43`G828G+B<E(`XPD\````$DQPT4QV$V)XTZ-A`:A
MZ]EN3(GF2<'K&TC!Y@5,"=Z)]DP!QDV)Z$G![0))P>`>08GS30GH28G%B<!(
M`X0D^````$TQQ40QZDV)W4B-C!&AZ]EN3(G:2<'M&TC!X@5,">J)TD@!T4R)
MXDG![`)(P>(>08G-3`GB38G$18G`23'41#'F38GL2(VT,*'KV6Y,B>A)P>P;
M2,'@!4P)X(G`2`'P3(G>2,'F'DG!ZP)!B<1,`X0D``$``$P)WDF)TXG22`.4
M)`@!``!),?-$,=E-B>--C80(H>O9;DR)X4G!ZQM(P>$%3`G9B<E)`<A,B>E)
MP>T"2,'A'D6)PTP)Z4F)]8GV2`.T)!`!``!),<U$,>A-B=U(C90"H>O9;DR)
MV$G![1M(P>`%3`GHB<!(`<),B>!)P>P"2,'@'D&)U4P)X$F)S(G)23'$13'@
M38GL3HV$!J'KV6Y,B>Y)P>P;2,'F!4P)YHGV3`'&38G82<'K`DG!X!Y!B?1-
M"=A)B<-(`XPD&`$``(G`33'#2`.$)"`!``!$,=I-B>-(C8P1H>O9;DR)XDG!
MZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"0H`0``
M23'51#'N38G=2(VT,*'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!
MYAY!B<5,">9)B=2)TD@#E"0P`0``23'T1#'A38GL38V$"*'KV6Y,B>E)P>P;
M2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)]DDQRT0QV$V)XT@#
MM"0X`0``2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V$2-'!!,B>A)P>T"2,'@'DP)
MZ$F)S8G)23'%B<)%,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GN3(NL)$`!
M``!&C30&38G@2<'L`DG!X!Y-">!,"<!$B<9)B<1(B=!((?!-(=Q)"<2XW+P;
MCTD!Q4P!Z4V)]4D!S$R)\4G![1M(P>$%3`GI28GU00',3(G92<'K`DC!X1Y,
M"=E!B<M)"<A-(?!-(=U-">A,BZPD2`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(
MP>(%3`GJ1HTL`DR)\DG![@)(P>(>3`GR38G>08G02`G132'&3"'A3`GQ3(NT
M)%`!``!)`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2--`Y,B>9)P>P"2,'F
M'DP)YDV)Q(GQ2`GR22',3"'J3`GB3(ND)%@!``!)`<1-`>--B?1,`=I-B?-)
MP>,%2<'L&TT)XT6-)!--B>M)P>T"2<'C'DT)ZTF)S42)VDP)WDDAU4PA]DP)
M[DR+K"1@`0``20'%30'H38GE3`'&38G@2<'M&TG!X`5-">A%C2PP38GP2<'N
M`DG!X!Y-"?!)B=9$B<9-"<-)(?9-(>--"?-,B[0D:`$``$D!QDP!\4V)[DD!
MRTR)Z4G![AM(P>$%3`GQ1HTT&4R)X4G![`)(P>$>3`GA28GT08G+20G(32'H
M32'<30G@3(ND)'`!``!)`<1,`>)-B?1)`=!,B?))P>P;2,'B!4P)XD:-)`),
MB>I)P>T"2,'B'DP)ZDV)W4&)T$@)T4TAQ4PA\4P)Z4R+K"1X`0``20'%3`'N
M38GE2`'Q3(GF2<'M&TC!Y@5,">Y$C2P.3(GV2<'N`DC!YAY,"?9-B<:)\4@)
M\DDASDPAXDP)\DR+M"2``0``20'&30'S38GN3`':38GK2<'C!4G![AM-"?-%
MC30338GC2<'L`DG!XQY-">-)B<Q$B=I,"=Y)(=1,(>Y,">9,BZ0DB`$``$D!
MQ$T!X$V)]$P!QDV)\$G![!M)P>`%30G@18TD,$V)Z$G![0))P>`>30GH28G5
M1(G&30G#22'U32'S30GK3(NL))`!``!)`<5,`>E-B>5)`<M,B>%)P>T;2,'A
M!4P)Z4:-+!E,B?%)P>X"2,'A'DP)\4F)]DD)R$&)RTTAWDTAX$T)\$R+M"28
M`0``20'&3`'R38GN20'03(GJ2<'N&TC!X@5,"?)&C30"3(GB2<'L`DC!XAY,
M">)-B=Q!B=!("=%-(<1,(>E,">%,BZ0DH`$``$D!Q$P!YDV)]$@!\4R)]DG!
M[!M(P>8%3`GF1(TD#DR)[DG![0)(P>8>3`GN38G%B?%("?))(<U,(?),">I,
MBZPDJ`$``$D!Q4T!ZTV)Y4P!VDV)XTG![1M)P>,%30GK18TL$TV)\TG![@))
MP>,>30GS28G.1(G:3`G>22'63"'F3`GV3(NT)+`!``!)`<9-`?!-B>Y,`<9-
MB>A)P>X;2<'@!4T)\$6--#!-B>!)P>P"2<'@'DT)X$F)U$2)QDT)PTDA]$TA
MZTT)XTR+I"2X`0``20'$3`'A38GT20'+3(GQ2<'L&TC!X05,">%&C2093(GI
M2<'M`DC!X1Y,">E)B?5!B<M)"<A-(?!-(=U-">A,BZPDP`$``$D!Q4P!ZDV)
MY4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG![@)-B=A(P>(>3`GR08G62`G1
M32'P3"'A3`G!3(N$),@!``!)`<!,`<9-B>A(`?%,B>Y)P>@;2,'F!4P)QD2-
M!`Y,B>9)P>P"3(GQ2,'F'DP)YD&)]$@)\DPAX4PAZD@)RDB+C"30`0``2`'!
M20'+3(G!2`.$)-@!``!,`=I-B<-(P>$%3`'P2<'K&TP)V8G)2`'*3(GI2<'M
M`DC!X1Y!B=-,">E-B>5!B<]("<Y-(?U,(<9,">Y-B=U(`?!,B=Y)P>T;2,'F
M!4P)[HGV2`'P3(G&2<'H`DC!YAY!B<5)"?"^UL%BRDPQP3'*2(N,).`!``!(
M`?%)`<Q,B>E,`>)-B>Q(P>$%2<'L&TP)X8G)2`'*3(G92,'A'DG!ZP)!B=1)
M"<M,B<%-B>9%B<!,,=E)P>X;,<A(BXPDZ`$``$@!\4D!STJ-##A,B>!(P>`%
M3`GPB<!,C30!3(GH2<'M`DR)V4C!X!Y%B?=%B=M)"<5(BX0D\`$``$PQZ4@!
M\#'*3(GY3`'`2,'I&T@!PDR)^$C!X`5("<A(BXPD^`$``(G`2`'"3(G@2`'Q
M2<'L`DC!X!Y,`=E-B>M!B=!,">!-B<1%B>U),<-)P>P;13'>3HT<,4R)P4C!
MX05,">&)R4D!RTR)^4G![P)(P>$>18G<20G/2(N,)``"``!(`?%,`>E)B<6)
MP$TQ_40QZDR-+!%,B>),B>%(P>D;2,'B!4@)RDR)P4G!Z`*)TDC!X1Y)`=5(
MBY0D"`(``$P)P4V)^$DQR$6)[D6)_T@!\D4QPT@!T$R)\DZ-!!A,B?!(P>H;
M2,'@!4@)T$B)RHG)B<!)`<!,B>!)P>P"2,'@'D6)PTD)Q$B+A"00`@``3#'B
M2`'P03'53(G:3`'X20'%3(G82,'@!4C!ZAM("=!,B?))P>X"B<!(P>(>20'%
M2(N$)!@"``!,"?)%B>](`?!(`<A,B>%%B>1(,=%!,<A,B?E)`<!,B?A(P>D;
M2,'@!4@)R(G`20'`3(G82<'K`DC!X!Y%B<9)"<-(BX0D(`(``$R)\4C!Z1M(
M`?!,`>!)B=2)TDTQW$4QY4Z-)"A,B?!(P>`%2`G(2(N,)"@"``")P$D!Q$R)
M^$@!\4G![P)(P>`>2`'*3(G918GE3`GX18G;2#'!03'(3(GI20'03(GJ2,'I
M&TC!X@5("<J)TDD!T$R)\DG![@)(P>(>18G'20G62(N4)#`"``!,B?E(P>D;
M2`'R3`':28G#B<!-,?-%,=Q.C1PB3(GZ2,'B!4@)RDR)Z4G![0*)TDC!X1Y)
M`=-(BY0D.`(``$P)Z46)W$@!\D@!T$R)\D6)]D@QRD$QT$R)XDD!P$R)X$C!
MZAM(P>`%2`G02(G*B<F)P$D!P$R)^$G![P)(P>`>18G%20G'2(N$)$`"``!(
M`?!,,?I,`?!!,=-,B>I)`<-,B>A(P>H;2,'@!4@)T$R)XDG![`*)P$C!XAY)
M`<-(BX0D2`(``$P)XD6)WDF)U$@!\$@!R$R)^46)_T@QT8G203'(2HT,`$R)
M\$V)\$G!Z!M(P>`%3`G`B<!(`<%,B>A)P>T"2,'@'D&)R$D)Q4B+A"10`@``
M33'L2`'P13'C38G$3`'X2<'L&TD!PTR)P$C!X`5,">")P$D!PTR)\$C!X!Y)
MP>X"18G<3`GP3(NT)%@"``!)`?9)`=9,B>I%B>U(,<(QT4F-%`Y,B>%-B>9)
MP>X;2,'A!4P)\8G)2`'*3(G!2<'H`DC!X1Y!B=9)"<A(BXPD8`(``$@!\4P!
MZ4F)Q8G`33'%13'K38GU20'+3(GQ2<'M&TC!X05,">F)R4D!RTR)X4G![`)(
MP>$>18G=20G,2(N,)&@"``!(`?%(`<A,B<%%B<!,,>$QRDB-#!!,B>A,B>I(
MP>H;2,'@!4@)T$R)\DG![@)(P>(>B<!)"=9(BY0D<`(``$@!P8G(2`'R3`'"
M38G@33'P13'#28G`3`':28G#2<'@!4G!ZQM-"=A)B<-(P>@"2<'C'D$!T$R)
MZDG![0))"<-(BX0D>`(``$C!XAY)"=5$B>)!`=M(`?!$`>U,B5\02`'"3(GP
M2(EO&$PQZ#'!2(T$"DR)PDR)P44!R$C!X@5(P>D;3(E'"$@)R@'000'"1`-W
M($R)%TR)=R!(BX0DB`(``$@S!1U@``!U$DB!Q)@"``!;74%<05U!7D%?P^A$
MRO__#Q]``$B#[`B_@````.A2RO__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)
M4`A(B4@02,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(
MPV9F+@\?A```````D$%72&/"059)B<9!54%428G\54F-;"0X4TB)\TB#[`A(
MBW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8W]XA?]T5D&]0```
M`$B)WD$I_44Y[D4/3NY(`>]-8_U,B?KHU\S__T&+1"1X1`'H08E$)'B#^$!T
M%4B#Q`A;74%<05U!7D%?PV8/'T0``$R)YT4I[DP!^^CRZ/__08/^/P^.W```
M`$&#[D!%B?=!P>\&18G]28/%`4G!Y09)`=WS#V\#3(GG2(/#0`\110#S#V]+
MT`\131#S#V]3X`\152#S#V];\`\173#HH.C__TPYZW7,0<'G!D4I_DECQDB#
M^`AR6TF+50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@IU4DI[4@!Q4B#Y?A(
M@_T(<AA(@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D>$B#Q`A;74%<05U!
M7D%?PY"H!'4H2(7`=.)!#[95`$&(5"0XJ`)TU$$/MU0%_F:)5`7^Z\=)B=WI
M</___T&+50!!B50D.$&+5`7\B50%_.NK059,C78X055!5%5(B?U32(M&*$B)
M\T2+9BA$BVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CB`!
M``"Z0````"G*B=%T#S'2B=:#P@'&!#``.<IR\TB)W^B*Y___9@_OP`\10SA)
MQT8P`````$$/$48000\11B!$B6MP2(G?1(EC=.A@Y___2(L#2(G?2,'H&(A%
M`$B+`TC!Z!"(10%(BP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H
M$(A%!4B+0PA(P>@(B$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(
MBT,02,'H"(A%"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!
MZ`B(10Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$42
M2(M#(%N(11-=05Q!74%>Z7S'__^Z.````#'_*<J#^@AS+O;"!'5KA=(/A`'_
M___&``#VP@(/A/7^__\QR6:)3!#^Z>G^__]F#Q^$``````")T4C'``````!(
MQT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X*U_O__@^+X,<")QH/`"$B)
M/#$YT'+SZ9[^___'``````#'1!#\`````.F+_O__2(L%C%L``$B#^/]T)%5(
MB>532(/L"+O(K4``_]!(@^L(2(L#2(/X_W7Q2(/$"%M=P\,`2(/L".BUS?__
M2(/$",,````N`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]C=7)P<F]C+V9I;&4`4$%2
M7U1%35``4$%27U!23T=.04U%`#H`+P`E<R5S)7,`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`55-%4@!365-414T`+W1M<"\`5$U01$E2`%1%
M35!$25(`5$5-4`!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`%!!
M5$@`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#8Q`"UE`"TM````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````
M````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M`````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%
M1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T
M7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T
M,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A
M<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]
M("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@
M3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D
M8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM
M>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U
M<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R
M;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A
M<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@
M/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?
M34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO
M=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H
M(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@
M(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL
M87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N
M9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O
M9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@
M<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-
M;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@
M*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD
M(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F
M:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=
M.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E
M871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E
M<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO
M861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@
M/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@
M/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\
M.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A
M73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H
M(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F
M*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E
M;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O
M;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@
M=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N
M?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F
M:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E
M:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@
M>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.
M?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY
M("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C
M:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?
M<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B
M=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L
M("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I
M"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M
M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE
M9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI
M;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T
M7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]
M("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%
M*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M(&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*``!#04-(10``<&5R;'AS:2YC`````````!0``````````7I2``%X$`$;
M#`<(D`$``$P````<````@(W__\8`````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P``````)```
M`&P`````CO__>P````!!#A"#`D<.(`)L"@X000X(00L``````$P```"4````
M6([__S<"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q4!
M"@XX00XP00XH0@X@0@X80@X00@X(00L`````/````.0```!(D/__00$```!"
M#A"-`D(.&(P#00X@A@1!#BB#!4<.P`%Z"@XH00X@00X80@X00@X(0PL`````
M`"0````D`0``6)'__U4`````00X0A@)0#AB#`T0.(&D.&$$.$%$."``D````
M3`$``)"1__^!`````$$.$(,"2@Z@`0)O"@X000X(00L`````/````'0!``#X
MD?__V0````!"#A"-`DH.&(P#20X@A@1!#BB#!4<.P`@"?PH.*$$.($$.&$(.
M$$(."$$+`````"P```"T`0``F)+__ZT`````00X0@P)*#J`(`F\*#A!!#@A%
M"UT*#A!&#@A%"P```!0```#D`0``&)/__R@``````````````!0```#\`0``
M,)/__P,``````````````#P````4`@``*)/__^\!````0@X0C0)*#AB,`T$.
M((8$00XH@P5*#L`)`EP*#BA!#B!!#AA"#A!"#@A&"P`````<````5`(``-B4
M__\B`````$$.$(,"7`X(`````````"0```!T`@``Z)3__T0`````2PX0@P)8
MPPX(70X0@P)##@@````````<````G`(``!"5__]<`0```$0.(`,B`0H."$H+
M`````!P```"\`@``4);__UD`````1`X@`DH*#@A""P``````%````-P"``"0
MEO__JP````!'#N`!````-````/0"```HE___"@$```!"#A",`DL.&(8#00X@
M@P1'#K"`!`*Q"@X@00X800X00@X(1@L````4````+`,```"8__\=`````$0.
M$%@."``T````1`,```B8__^Q`````$(.$(P"00X8A@-)#B"#!$0.,`)&"@X@
M00X800X00@X(1@L``````%0```!\`P``D)C__XT&````0@X0C@)"#AB-`TH.
M((P$00XHA@5!#C"#!D<.@`,#E`(*#C!!#BA!#B!"#AA"#A!"#@A!"P.K`0Z(
M`TL.D`-;#H@#00Z``P`T````U`,``,B>__\#`@```$(.$(P"1@X8A@-!#B"#
M!$0.,`-I`0H.($$.&$$.$$(."$8+`````!P````,!```H*#__U$`````00X0
M@P)9"@X(1@ML#@@`)````"P$``"PA/__`0(```!!#A"#`D0.0`-=`0H.$$$.
M"$$+`````$P```!4!```R*#__PP6````0@X0CP)&#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1P[0!0/G%0H..$$.,$$.*$(.($(.&$(.$$(."$$+````%```
M`*0$``"(MO__5`````!$#A`"3PX(9````+P$``#0MO__H`$```!"#A"/`D4.
M&(X#10X@C01"#BB,!40.,(8&1@XX@P='#D`"8`H..$$.,$$.*$(.($(.&$(.
M$$(."$<+`L0*#CA!#C!!#BA"#B!"#AA"#A!"#@A""P````!$````)`4```BX
M___U`0```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#1@$*#BA$#B!"#AA"
M#A!"#@A%"P`````````````D````;`4``)!____@`P````X01@X82@\+=PB`
M`#\:.RHS)"(```````````$;`SMH^O__'````&Q____4____3(/__Y3^__\,
MB/__A/K__]R(___4^O__7(G___SZ__^<B___3/O__^R,__^,^___3(W__[3[
M___<C?__W/O__[R.__\<_/__;(___TS\__^<C___9/S__ZR/__]\_/__G)'_
M_[S\___,D?__W/S__QR2__\$_?__?)/__R3]___<D___1/W__XR4__]<_?__
MG)7__Y3]__^\E?__K/W__WR6___D_?__#)W__SS^__\<G___=/[__XR?__^\
M_O__G+7__PS____\M?__)/___YRW__^,____`P````````"@JT````````(`
M````````N`4````````7`````````$`20```````%``````````'````````
M``<`````````R!%````````(`````````'@`````````"0`````````8````
M`````!4````````````````````&`````````%`"0```````"P`````````8
M``````````4`````````.`M````````*`````````*,$````````]?[_;P``
M``#@#T````````$`````````(`0````````!`````````#`$`````````0``
M``````!`!`````````$`````````2P0````````!`````````%4$````````
M`0````````!C!`````````$`````````*``````````,`````````/@70```
M````#0````````!H4D```````!T`````````<`0```````#P__]O`````-00
M0```````_O__;P````"4$4```````/___V\``````0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````D*E`````````````````````````````)AA`````
M```V&$```````$880```````5AA```````!F&$```````'880```````AAA`
M``````"6&$```````*880```````MAA```````#&&$```````-880```````
MYAA```````#V&$````````890```````%AE````````F&4```````#890```
M````1AE```````!6&4```````&890```````=AE```````"&&4```````)89
M0```````IAE```````"V&4```````,890```````UAE```````#F&4``````
M`/890```````!AI````````6&D```````"8:0```````-AI```````!&&D``
M`````%8:0```````9AI```````!V&D```````(8:0```````EAI```````"F
M&D```````+8:0```````QAI```````#6&D```````.8:0```````]AI`````
M```&&T```````!8;0```````)AM````````V&T```````$8;0```````5AM`
M``````!F&T```````'8;0```````AAM```````"6&T```````*8;0```````
MMAM```````#&&T```````-8;0```````YAM```````!X4D``````````````
M````"E!!4BYP;0H``````````(A50```````__________\``````````/__
M________````````````1T-#.B`X+C,@6T1R86=O;D9L>5T@4F5L96%S92\R
M,#$Y+3`R+3(R``````0````)````!````$=.50!G;VQD(#$N,38`````+G1E
M>'0`+F=O=``N8V]M;65N=``N9V]T+G!L=``N<F5L82YP;'0`+FEN:70`+F)S
M<P`N9'1O<G,`+F-T;W)S`"YD>6YS='(`+F5H7V9R86UE7VAD<@`N9VYU+G9E
M<G-I;VY?<@`N:6YT97)P`"YR96QA+F1Y;@`N9VYU+G9E<G-I;VX`+FYO=&4N
M9VYU+F=O;&0M=F5R<VEO;@`N9'EN<WEM`"YF:6YI`"YG;G4N:&%S:``N;F]T
M92YT86<`+F5H7V9R86UE`"YT;5]C;&]N95]T86)L90`N9'EN86UI8P`N<VAS
M=')T86(`+G)O9&%T80`N9&%T80``````````````````````````````````
M````````````````````````````````````````````````````````````
M`&8````!`````@```````````D`````````"````````%0``````````````
M``````$```````````````````"T````!P````(`````````&`)````````8
M`@```````#@````````````````````$````````````````````G`````L`
M```"`````````%`"0```````4`(```````#H"`````````0````!````"```
M```````8`````````$$````#`````@`````````X"T```````#@+````````
MHP0```````````````````$```````````````````"J````]O__;P(`````
M````X`]```````#@#P```````/0``````````P`````````(````````````
M````````>````/___V\"`````````-000```````U!````````"^````````
M``,``````````@`````````"`````````%<```#^__]O`@````````"4$4``
M`````)01````````,``````````$`````0````0```````````````````!N
M````!`````(`````````R!%```````#($0```````'@``````````P``````
M```(`````````!@`````````'@````0```!"`````````$`20```````0!(`
M``````"X!0````````,````+````"``````````8`````````"@````!````
M!@````````#X%T```````/@7````````$P````````````````````0`````
M```````````````C`````0````8`````````$!A````````0&````````.`#
M```````````````````0`````````!```````````0````$````&````````
M`/`;0```````\!L```````!W-@``````````````````$```````````````
M`````*0````!````!@````````!H4D```````&A2````````#@``````````
M``````````0```````````````````#K`````0````(`````````>%)`````
M``!X4@```````))````````````````````(````````````````````O@``
M``$``'`"`````````!"30```````$),```````"4!0``````````````````
M"````````````````````$D````!``!P`@````````"DF$```````*28````
M````[`````````````````````0```````````````````#8````!@````,`
M````````D*E```````"0F0`````````"````````!``````````(````````
M`!``````````!P````$````#`````````)"K0```````D)L````````0````
M````````````````"````````````````````!4````!`````P````````"@
MJT```````*";``````````(```````````````````@`````````````````
M``#S`````0````,`````````H*U```````"@G0```````"@`````````````
M```````(````````````````````.@````$````#`````````,BM0```````
MR)T````````0````````````````````"````````````````````#,````!
M`````P````````#8K4```````-B=````````$`````````````````````@`
M``````````````````#(`````0````,`````````Z*U```````#HG0``````
M```````````````````````(````````````````````+@````@````#````
M``````"N0```````Z)T```````"A````````````````````(```````````
M``````````P````!````,````````````````````.B=````````*0``````
M``````````````$``````````0````````"%````!P``````````````````
M```````4G@```````!P````````````````````$````````````````````
MX0````,`````````````````````````,)X```````#Y````````````````
3`````0``````````````````````
